pub struct SingleTimestampStreamData {
pub stream_id: String,
pub timestamp: u64,
pub source: Option<String>,
pub value: Value,
pub channel_name: Option<String>,
pub channel_unit: Option<String>,
pub multi_values: Vec<Value>,
pub channel_names: Vec<String>,
pub channel_units: HashMap<String, String>,
}Fields
stream_id: Stringtimestamp: u64source: Option<String>Identifies the origin of this stream for metrics purposes. When present,
stream ingress rollups are tracked for this source via
connect_metrics::ConnectMetrics::track_stream_ingress_rollup. When
absent, rollups are tracked under the "unknown" source.
value: Valuechannel_name: Option<String>channel_unit: Option<String>multi_values: Vec<Value>channel_names: Vec<String>channel_units: HashMap<String, String>Trait Implementations
Sourceimpl Clone for SingleTimestampStreamData
impl Clone for SingleTimestampStreamData
Sourcefn clone(&self) -> SingleTimestampStreamData
fn clone(&self) -> SingleTimestampStreamData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SingleTimestampStreamData
impl Debug for SingleTimestampStreamData
Sourceimpl<'de> Deserialize<'de> for SingleTimestampStreamData
impl<'de> Deserialize<'de> for SingleTimestampStreamData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more